==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/BookingWorkTimeSlot.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.LocalTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "start", 
    "end"})
@JsonInclude(Include.NON_NULL)
public class BookingWorkTimeSlot implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("start")
    protected LocalTime start;

    @JsonProperty("end")
    protected LocalTime end;

    protected BookingWorkTimeSlot() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.bookingWorkTimeSlot";
    }

    @Property(name="start")
    @JsonIgnore
    public Optional<LocalTime> getStart() {
        return Optional.ofNullable(start);
    }

    public BookingWorkTimeSlot withStart(LocalTime start) {
        BookingWorkTimeSlot _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.bookingWorkTimeSlot");
        _x.start = start;
        return _x;
    }

    @Property(name="end")
    @JsonIgnore
    public Optional<LocalTime> getEnd() {
        return Optional.ofNullable(end);
    }

    public BookingWorkTimeSlot withEnd(LocalTime end) {
        BookingWorkTimeSlot _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.bookingWorkTimeSlot");
        _x.end = end;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private LocalTime start;
        private LocalTime end;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder start(LocalTime start) {
            this.start = start;
            this.changedFields = changedFields.add("start");
            return this;
        }

        public Builder end(LocalTime end) {
            this.end = end;
            this.changedFields = changedFields.add("end");
            return this;
        }

        public BookingWorkTimeSlot build() {
            BookingWorkTimeSlot _x = new BookingWorkTimeSlot();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.bookingWorkTimeSlot";
            _x.start = start;
            _x.end = end;
            return _x;
        }
    }

    private BookingWorkTimeSlot _copy() {
        BookingWorkTimeSlot _x = new BookingWorkTimeSlot();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.start = start;
        _x.end = end;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("BookingWorkTimeSlot[");
        b.append("start=");
        b.append(this.start);
        b.append(", ");
        b.append("end=");
        b.append(this.end);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/BookingWorkTimeSlot.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.LocalTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "end", 
    "start"})
@JsonInclude(Include.NON_NULL)
public class BookingWorkTimeSlot implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("end")
    protected LocalTime end;

    @JsonProperty("start")
    protected LocalTime start;

    protected BookingWorkTimeSlot() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.bookingWorkTimeSlot";
    }

    @Property(name="end")
    @JsonIgnore
    public Optional<LocalTime> getEnd() {
        return Optional.ofNullable(end);
    }

    public BookingWorkTimeSlot withEnd(LocalTime end) {
        BookingWorkTimeSlot _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.bookingWorkTimeSlot");
        _x.end = end;
        return _x;
    }

    @Property(name="start")
    @JsonIgnore
    public Optional<LocalTime> getStart() {
        return Optional.ofNullable(start);
    }

    public BookingWorkTimeSlot withStart(LocalTime start) {
        BookingWorkTimeSlot _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.bookingWorkTimeSlot");
        _x.start = start;
        return _x;
    }

    public BookingWorkTimeSlot withUnmappedField(String name, Object value) {
        BookingWorkTimeSlot _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private LocalTime end;
        private LocalTime start;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder end(LocalTime end) {
            this.end = end;
            this.changedFields = changedFields.add("end");
            return this;
        }

        public Builder start(LocalTime start) {
            this.start = start;
            this.changedFields = changedFields.add("start");
            return this;
        }

        public BookingWorkTimeSlot build() {
            BookingWorkTimeSlot _x = new BookingWorkTimeSlot();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.bookingWorkTimeSlot";
            _x.end = end;
            _x.start = start;
            return _x;
        }
    }

    private BookingWorkTimeSlot _copy() {
        BookingWorkTimeSlot _x = new BookingWorkTimeSlot();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.end = end;
        _x.start = start;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("BookingWorkTimeSlot[");
        b.append("end=");
        b.append(this.end);
        b.append(", ");
        b.append("start=");
        b.append(this.start);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
